==> haskell-boxes-0.1.5-339-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-boxes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 boxes
version:              0.1.5
visibility:           public
id:                   boxes-0.1.5-GtyWoAp8URx4Q232lQg7iN
key:                  boxes-0.1.5-GtyWoAp8URx4Q232lQg7iN
license:              BSD-3-Clause
maintainer:           David Feuer <David.Feuer@gmail.com>
author:               Brent Yorgey
synopsis:             2D text pretty-printing library
description:
    A pretty-printing library for laying out text in
    two dimensions, using a simple box model.

category:             Text
abi:                  270b3c66696f88e4879ca72cedd5266f
exposed:              True
exposed-modules:      Text.PrettyPrint.Boxes
import-dirs:          /usr/lib/ghc-9.6.6/site-local/boxes-0.1.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/boxes-0.1.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/boxes-0.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-boxes
hs-libraries:         HSboxes-0.1.5-GtyWoAp8URx4Q232lQg7iN
depends:              base-4.18.2.1 split-0.2.5-3RnrRTIeHLc8NBcVaUtFqR
haddock-interfaces:   /usr/share/doc/haskell-boxes/html/boxes.haddock
haddock-html:         /usr/share/doc/haskell-boxes/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-boxes-0.1.5-340-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-boxes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 boxes
version:              0.1.5
visibility:           public
id:                   boxes-0.1.5-2uI8yjqHdVO3TV9dBMzo8v
key:                  boxes-0.1.5-2uI8yjqHdVO3TV9dBMzo8v
license:              BSD-3-Clause
maintainer:           David Feuer <David.Feuer@gmail.com>
author:               Brent Yorgey
synopsis:             2D text pretty-printing library
description:
    A pretty-printing library for laying out text in
    two dimensions, using a simple box model.

category:             Text
abi:                  b00f6389d4c9f01a2eeef8c4a51f5eaa
exposed:              True
exposed-modules:      Text.PrettyPrint.Boxes
import-dirs:          /usr/lib/ghc-9.6.6/site-local/boxes-0.1.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/boxes-0.1.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/boxes-0.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-boxes
hs-libraries:         HSboxes-0.1.5-2uI8yjqHdVO3TV9dBMzo8v
depends:              base-4.18.2.1 split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8
haddock-interfaces:   /usr/share/doc/haskell-boxes/html/boxes.haddock
haddock-html:         /usr/share/doc/haskell-boxes/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
